@@ -21,7 +21,7 @@ import pyramid.httpexceptions as exc
 from sqlalchemy.orm.exc import MultipleResultsFound, NoResultFound
 
 from tropofy.database import DBSession
-from tropofy.database.tropofy_orm import json_renderer, DynamicSchemaName
+from tropofy.database.tropofy_orm import json_renderer, DynamicSchemaName, enable_sqlite_foreign_keys, encryption
 from tropofy.file_io import FileIoConfig
 from sqlalchemy import create_engine
 
@@ -38,11 +38,17 @@ def main(global_config, **settings):
     # Delay imports, so that DynamicSchemaName.use_app_schemas can be updated correctly before AppDataSet etc. tables are imported.
     from tropofy.app import App, AppDataSet, AppManager, LoadedApps
     from tropofy.widgets import Widget
-    App.global_sqla_engine = create_engine(global_sqla_engine) if global_sqla_engine else None
 
-    authn_policy = AuthTktAuthenticationPolicy('lDklAS*)(dA0pDJpasJDIJPkadgsosecret5872', callback=groupfinder, hashalg='sha512')
+    if global_sqla_engine:
+        App.global_sqla_engine = create_engine(global_sqla_engine)
+    else:  # Don't enable these by default if not using SQLite. In memory sqlite db for decrypting things benefits from NOT having FK's enforced (especially on grids).
+        enable_sqlite_foreign_keys()
+
+    encryption.global_aes_key = settings.get('encryption.global_aes_key')
+
+    authn_policy = AuthTktAuthenticationPolicy(settings['auth.policy_secret'], callback=groupfinder, hashalg='sha512')
     authz_policy = ACLAuthorizationPolicy()
-    my_session_factory = UnencryptedCookieSessionFactoryConfig('itsatropofyseekreet')
+    my_session_factory = UnencryptedCookieSessionFactoryConfig(settings['auth.session_factory_secret'])
     config = Configurator(
         settings=settings,
         root_factory=RootFactory,
