@@ -72,7 +72,7 @@ def log_activity(request, description):
 def run_app(request):
     app = request.app
     result = proxy_request(request, data={
-        'step_groups': [step_group.serialise(app=app, authenticated_user=authenticated_userid(request)) for step_group in app.get_ordered_step_groups()],
+        'step_groups': [step_group.serialise(app=app, authenticated_user=authenticated_userid(request)) for step_group in app.step_groups],
         'app_init_config': app._get_app_init_config(authenticated_user=authenticated_userid(request)),
     })
     return Response(result.content)
@@ -122,7 +122,7 @@ def export_data_set(request):
         log_activity(request, ("Export data set: '{name}'".format(name=request.data_set.name)))
     else:
         log_activity(request, 'Export Excel Template')
-    return request.app.export_data_set(request.data_set)
+    return request.app._export_data_set(request.data_set)
 
 
 ### Data Set Management ###
@@ -130,11 +130,11 @@ def export_data_set(request):
 def create_new_data_set(request):
     app = request.app
     if app is not None:
-        data_set = app.create_new_data_set_for_user(
+        data_set = app._create_new_data_set_for_user(
             authenticated_userid(request),
             request.POST['data_set_name'],
         )
-        app.populate_data_set_from_template(data_set, request.POST['data_set_template'])
+        app._populate_data_set_from_template(data_set, request.POST['data_set_template'])
         return {
             'success': True,
             'dataSetId': data_set.id
@@ -183,9 +183,11 @@ def login(request):
 @view_config(route_name='logout', renderer='string')
 def logout(request):
     headers = forget(request)
-    data = request.app.get_home_page_configuration()
+    app = request.app
+    data = app._get_home_page_configuration()
     data.update({
-        'login_screen_default_is_create_account': request.app.is_login_screen_default_create_account(),
+        'login_screen_default_is_create_account': app.is_login_screen_default_create_account(),
+        'app_allows_account_creation': app.app_allows_account_creation(),
     })
     result = proxy_request(
         request,
