@@ -13,14 +13,14 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 
 from widgets import Widget, WidgetConfigException
 from form_widget import Form  # Needs to be before GridWidget
-from file_upload_widget import FileUpload  # Used by DataSets. Import order is important.
+from file_upload_widget import FileUpload, ClassDataFileUpload  # Used by DataSets. Import order is important.
 from grid_widget import GridWidget
 from grid_widget.simple_grid import SimpleGrid
 from kml_map_widget import KMLMap
 from chart_widget import Chart, FilteredChart
 from execute_function_widget import ExecuteFunction
 from image_widget import StaticImage
-from custom_export_widget import CustomExport, ExportDataSet
+from custom_export_widget import CustomExport, ExportDataSet, ExportExampleExcelData
 from download_file_from_url_widget import DownloadFileFromUrl
 from form_widget import ParameterForm, Filter, FilterMixin
 from download_file_from_url_widget import DownloadFileFromUrl
