@@ -85,12 +85,12 @@ class Form(Widget):
             self.label = label if label is not None else self.name
             # self.compute_options_from = compute_options_from if self.options == [] and self.is_select_element else None
 
-        def serialise(self):
+        def _serialise(self):
             return {
                 'name': self.name,
                 'inputType': self.input_type,
                 'defaultValue': self.default_value,
-                'options': [o.serialise() for o in self.options] if self.is_select_element else self.options,
+                'options': [o._serialise() for o in self.options] if self.is_select_element else self.options,
                 'computeOptionsFrom': self.compute_options_from,
                 'label': self.label,
                 'hidden': self.hidden,
@@ -199,13 +199,13 @@ class Form(Widget):
                 self.text = text if text else self.value
                 self.dependent_option_lists = dependent_option_lists if dependent_option_lists else {}
 
-            def serialise(self):
+            def _serialise(self):
                 return {
                     'value': self.value,
                     'text': self.text,
                     'dependentOptionLists': [{
                         'name': name,
-                        'options': [o.serialise() for o in options]
+                        'options': [o._serialise() for o in options]
                     } for name, options in self.dependent_option_lists.iteritems()]
                 }
 
@@ -242,7 +242,7 @@ class Form(Widget):
             form_elements = form_elements if form_elements else []
 
             return {
-                'formElements': [e.serialise() for e in form_elements],
+                'formElements': [e._serialise() for e in form_elements],
                 # 'formTitle': self.get_title(data_set, form_values=form_values),  // TODO: Need to add **kwargs before can pass form_values.
                 # 'isAutoSubmit': self.is_autosubmit(data_set, form_values=form_values),
                 # 'isSubmitEntireForm': self.is_submit_entire_form(data_set, form_values=form_values),
@@ -254,7 +254,7 @@ class Form(Widget):
         form_elements = form_elements if form_elements else []
 
         return {
-            'formElements': [e.serialise() for e in form_elements],
+            'formElements': [e._serialise() for e in form_elements],
             'formTitle': self.get_title(data_set),
             'isAutoSubmit': self.is_autosubmit(data_set),
             'isSubmitEntireForm': self.is_submit_entire_form(data_set),
@@ -271,7 +271,7 @@ class Form(Widget):
         """
         raise NotImplementedError
 
-    def process_data(self, data, data_set):
+    def process_data(self, data, data_set, **kwargs):
         """Process data from form submit.
 
         :param data: Dict of name:value pairs, submitted from the form.
@@ -292,7 +292,7 @@ class Form(Widget):
         """
         raise NotImplementedError
 
-    def get_title(self, data_set):
+    def get_title(self, data_set, **kwargs):
         """A title for the form. If not implemented then there will be no title.
 
         :param data_set: current data set.
@@ -302,7 +302,7 @@ class Form(Widget):
         """
         return None
 
-    def is_autosubmit(self, data_set):
+    def is_autosubmit(self, data_set, **kwargs):
         """Determines whether a form autosubmits on value change or has a submit button.
 
         - True (default): The entire form will autosubmit when any value is changed. No submit button will be shown.
@@ -315,7 +315,7 @@ class Form(Widget):
         """
         return True
 
-    def is_submit_entire_form(self, data_set):
+    def is_submit_entire_form(self, data_set, **kwargs):
         """Determines whether a form on submit submits the entire form.
 
         Default False - means only form element that has changed is submitted.
@@ -326,7 +326,7 @@ class Form(Widget):
         """
         return False
 
-    def hide_submit_button(self, data_set):
+    def hide_submit_button(self, data_set, **kwargs):
         """Hides the form submit button. Advanced use only - it is usually safe to rely on default value.
 
         By default, submit button is hidden if :func:`tropofy.widgets.Form.is_autosubmit` returns True, and False otherwise.
@@ -350,7 +350,7 @@ class Form(Widget):
         formats.update(custom_formats)
         return formats
 
-    def get_datetime_display_formats(self):
+    def get_datetime_display_formats(self, **kwargs):
         """ Specify custom display formats to display datetimes, dates, and times in a form.
 
         Use format strings specified by `MomentJS <http://momentjs.com/docs/#/parsing/string-format/>`_. Note that these are slightly different to string-formats used in Python.
@@ -410,10 +410,10 @@ class ParameterForm(Form):
                 ))
         return elements
 
-    def get_title(self, data_set):
+    def get_title(self, data_set, **kwargs):
         return self.title
 
-    def process_data(self, data, data_set):
+    def process_data(self, data, data_set, **kwargs):
         results = []
         for name, value in data.iteritems():
             try:
@@ -468,14 +468,14 @@ class Filter(Form):
                 })
         return values
 
-    def process_data(self, data, data_set):
+    def process_data(self, data, data_set, **kwargs):
         for name, value in data.items():
             data_set.set_var(self._get_var_name(name), value)
 
     def _get_var_name(self, element_name):
         return 'filter_%s_%s' % (self.id, element_name)
 
-    def is_submit_entire_form(self, data_set):
+    def is_submit_entire_form(self, data_set, **kwargs):
         return True
 
     def _refresh(self, request, data_set, **kwargs):
@@ -488,7 +488,7 @@ class Filter(Form):
             element.default_value = form_element_values[element.name]
 
         refresh_dict = super(Filter, self).refresh(request, data_set)
-        refresh_dict['formElements'] = [e.serialise() for e in form_elements]  # Have to overide here, as only other option would be to pass form_elements to Form.refresh -> This is a framework function though, so this would be weird...
+        refresh_dict['formElements'] = [e._serialise() for e in form_elements]  # Have to overide here, as only other option would be to pass form_elements to Form.refresh -> This is a framework function though, so this would be weird...
         return refresh_dict
 
     def _set_filter_var_to_defaults(self, data_set):
@@ -509,7 +509,7 @@ class FilterMixin(object):
 
     .. note:: It is important to inherit from FilterMixin before inheriting from another Widget. Otherwise the relationship to the filter may not work correctly.
 
-    :param data_filter: A filter widget that filters this chart.
+    :param data_filter: A filter widget that filters this widget.
     :type data_filter: :class:`tropofy.widgets.Filter`
     """
     def __init__(self, data_filter):
@@ -518,7 +518,7 @@ class FilterMixin(object):
             self.filter.add_event_subscription('refreshed', self.actions('show'))  # After filter initially loaded('refreshed'), show the chart.
             self.filter.add_event_subscription('formSubmitSuccess', self.actions('refresh'))
 
-    def get_filter_values(self, data_set):
+    def get_filter_values(self, data_set, **kwargs):
         """Helper method that returns the values of the filter.
 
         Use this method within any methods of your widget with ``self.get_filter_values(data_set)``.
