@@ -62,7 +62,7 @@ class Road(DataSetMixin):
         )
     
 class IntersectionKMLMap(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
 
         def LongLat(l):
@@ -77,7 +77,7 @@ class IntersectionKMLMap(KMLMap):
 
 
 class RoadKMLMap(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
 
         def LongLat(l):
@@ -97,7 +97,7 @@ class RoadKMLMap(KMLMap):
 
 
 class SpanningTreeKMLMap(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
 
         def LongLat(l):
@@ -129,10 +129,10 @@ class ExecuteSolverFunction(ExecuteFunction):
 
     execution_data_set = None
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Find Spanning Tree"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         ExecuteSolverFunction.execution_data_set = data_set
         exmod.callback(self.add_road_to_spanning_tree)
 
@@ -163,13 +163,13 @@ class ExecuteSolverFunction(ExecuteFunction):
 
 class SpanningTreeApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "Minimum Spanning Tree"
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Data for Brisbane": self.load_example_data_for_brisbane}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Input')
         step_group1.add_step(Step(
             name='Intersections',
@@ -199,10 +199,10 @@ class SpanningTreeApp(AppWithDataSets):
     def load_example_data_for_brisbane(data_set):
         read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('spanning_tree_example_data.xlsx'))
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/spanning_tree.png'
     
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {'content_app_name_header': '''
                 <div>
                 <span style="vertical-align: middle;">Minimum Spanning Tree</span>
