@@ -129,7 +129,7 @@ class NetworkFlow(DataSetMixin):
     
 class MapNodeInput(KMLMap):
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
 
         node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
@@ -147,7 +147,7 @@ class MapArcInput(KMLMap):
         hex_colours = ['FFC86602','FF0101F9','FF0FB5F2','FF3B9300',]
         return hex_colours[n % 1]
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
 
         node_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
@@ -172,7 +172,7 @@ class MapFlowOutput(KMLMap):
         hex_colours = ['FFC86602','FF0101F9','FF0FB5F2','FF3B9300',]
         return hex_colours[n % 4]
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
 
         kml = Kml()
 
@@ -252,10 +252,10 @@ class NetworkOutflowChart(Chart):
 
 class ExecuteSolverFunction(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Network Flow Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         '''
         Copyright 2013, Gurobi Optimization, Inc.
         
@@ -328,13 +328,13 @@ class ExecuteSolverFunction(ExecuteFunction):
 
 class NetworkFlowOptimisationApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Network Flow Optimiser'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo data set from Gurobi": self.load_network_flow_example_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Input')
         step_group1.add_step(Step(
             name='Commodities',
@@ -397,10 +397,10 @@ class NetworkFlowOptimisationApp(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/network_flow.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
