@@ -50,7 +50,7 @@ class TravellingSalesManStop(DataSetMixin):
 
 
 class KMLMapForStops(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
         stop_style = Style(iconstyle=IconStyle(scale=0.8, icon=Icon(href='https://maps.google.com/mapfiles/kml/paddle/blu-circle-lv.png')))
         stops = kml.newfolder(name="Stops")
@@ -60,7 +60,7 @@ class KMLMapForStops(KMLMap):
 
 
 class KMLMapForRoute(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
 
         kml = Kml()
 
@@ -88,10 +88,10 @@ class KMLMapForRoute(KMLMap):
 
 class ExecuteGurobiSolver(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Travelling Salesman Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         if len(data_set.query(TravellingSalesManStop).all()) > 30:
             data_set.send_progress_message("More than 30 stops exceeds to license limits of the free trial version of Gurobi")
         else:
@@ -100,13 +100,13 @@ class ExecuteGurobiSolver(ExecuteFunction):
 
 class GurobiRosteringApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Travelling Salesman Solver'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo 30 Stop random data set": load_random_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Enter your stops')
         step_group1.add_step(Step(name='Enter your stops', widgets=[SimpleGrid(TravellingSalesManStop)]))
         step_group1.add_step(Step(name='Review the stops', widgets=[KMLMapForStops()]))
@@ -125,10 +125,10 @@ class GurobiRosteringApp(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/travelling_salesman.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
