@@ -67,7 +67,7 @@ class Flow(DataSetMixin):
 
 class KMLMapInput(KMLMap):
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
 
         kml = Kml()
 
@@ -91,7 +91,7 @@ class KMLMapOutput(KMLMap):
         hex_colours = ['FFFFFF00', 'FF00F5FF', 'FF00FA9A', 'FFC0FF3E', 'FFCAE1FF', 'FFFCE6C9', 'FFEE6A50', 'FFFF6A6A', 'FF7171C6', 'FF71C671']
         return hex_colours[n % 10]
 
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
 
         kml = Kml()
         flows = data_set.query(Flow).all()
@@ -121,10 +121,10 @@ class KMLMapOutput(KMLMap):
 
 class ExecuteSolverFunction(ExecuteFunction):
 
-    def get_button_text(self):
+    def get_button_text(self, **kwargs):
         return "Solve Facility Location Problem"
 
-    def execute_function(self, data_set):
+    def execute_function(self, data_set, **kwargs):
         if len(data_set.query(Shop).all()) > 200:
             data_set.send_progress_message("You can only solve problems with 200 shops of fewer using the free version of this app")
         else:
@@ -152,13 +152,13 @@ class PlantSizePieChart(Chart):
 
 class MyFacilityLocationSolverApp(AppWithDataSets):
 
-    def get_name(self):
+    def get_name(self, **kwargs):
         return 'Facility Location Optimisation'
 
-    def get_examples(self):
+    def get_examples(self, **kwargs):
         return {"Demo data for Brisbane": load_brisbane_data}
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         step_group1 = StepGroup(name='Enter your data')
         step_group1.add_step(Step(
             name='Enter your locations',
@@ -192,10 +192,10 @@ class MyFacilityLocationSolverApp(AppWithDataSets):
 
         return [step_group1, step_group2, step_group3]
 
-    def get_icon_url(self):
+    def get_icon_url(self, **kwargs):
         return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/facility_location.png'
 
-    def get_home_page_content(self):
+    def get_home_page_content(self, **kwargs):
         return {
             'content_app_name_header': '''
             <div>
