@@ -25,8 +25,8 @@ class Store(DataSetMixin):
 
 
 class MyFirstApp(AppWithDataSets):
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "My First App"
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         return [StepGroup(name='Stores', steps=[Step(name='Stores', widgets=[SimpleGrid(Store)])])]
