@@ -13,7 +13,7 @@ class Store(DataSetMixin):
 
 
 class MyKMLMap(KMLMap):
-    def get_kml(self, data_set):
+    def get_kml(self, data_set, **kwargs):
         kml = Kml()
         for store in data_set.query(Store).all():
             kml.newpoint(name=store.name, coords=[(store.longitude, store.latitude)])
@@ -21,10 +21,10 @@ class MyKMLMap(KMLMap):
 
 
 class MyFirstApp(AppWithDataSets):
-    def get_name(self):
+    def get_name(self, **kwargs):
         return "My First App"
 
-    def get_gui(self):
+    def get_gui(self, **kwargs):
         return [
             StepGroup(name='Stores', steps=[Step(name='Stores', widgets=[SimpleGrid(Store)])]),
             StepGroup(name='Map', steps=[Step(name='Map', widgets=[MyKMLMap()])])
